summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/app_list/app_list_controller_delegate.h
diff options
context:
space:
mode:
authorxiyuan@chromium.org <xiyuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-10 22:21:18 +0000
committerxiyuan@chromium.org <xiyuan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-10 22:21:18 +0000
commit2c4d75ca9211a2dd2d477d0c6cc17868d5ef15e6 (patch)
treece388a76263b960592fb75deae504db272bca17e /chrome/browser/ui/app_list/app_list_controller_delegate.h
parent14141eaf80a9de9bc3a120ee7f9142b2d51dc564 (diff)
downloadchromium_src-2c4d75ca9211a2dd2d477d0c6cc17868d5ef15e6.zip
chromium_src-2c4d75ca9211a2dd2d477d0c6cc17868d5ef15e6.tar.gz
chromium_src-2c4d75ca9211a2dd2d477d0c6cc17868d5ef15e6.tar.bz2
app_list: Show disabled/terminated apps.
- Include disabled and terminated apps in AppsModelBuilder; - Update icon when apps are loaded/unloaded; - Run ExtensionEnableFlow when clicked on disabled/terminated app; BUG=157996 TEST=Verify disabled/terminated apps shows up in app launcher. R=sky@chromium.org,benwells@chromium.org Review URL: https://chromiumcodereview.appspot.com/11573026 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@176173 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/app_list/app_list_controller_delegate.h')
-rw-r--r--chrome/browser/ui/app_list/app_list_controller_delegate.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/chrome/browser/ui/app_list/app_list_controller_delegate.h b/chrome/browser/ui/app_list/app_list_controller_delegate.h
index dff9bbd..4fb8cf3 100644
--- a/chrome/browser/ui/app_list/app_list_controller_delegate.h
+++ b/chrome/browser/ui/app_list/app_list_controller_delegate.h
@@ -7,6 +7,8 @@
#include <string>
+#include "ui/gfx/native_widget_types.h"
+
class Profile;
// Interface to allow the view delegate to call out to whatever is controlling
@@ -25,15 +27,18 @@ class AppListControllerDelegate {
// Handle the view being activated or deactivated.
virtual void ViewActivationChanged(bool active);
+ // Get app list window.
+ virtual gfx::NativeWindow GetAppListWindow() = 0;
+
// Control of pinning apps.
virtual bool IsAppPinned(const std::string& extension_id);
virtual void PinApp(const std::string& extension_id);
virtual void UnpinApp(const std::string& extension_id);
virtual bool CanPin() = 0;
- // Be aware of the extension uninstalling flow.
- virtual void AboutToUninstallApp() {}
- virtual void UninstallAppCompleted() {}
+ // Be aware of the extension prompt (either uninstalling flow or enable flow).
+ virtual void OnShowExtensionPrompt() {}
+ virtual void OnCloseExtensionPrompt() {}
// Whether the controller supports showing the Create Shortcuts dialog.
virtual bool CanShowCreateShortcutsDialog() = 0;